zfit\_physics package
=====================

.. automodule:: zfit_physics
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   zfit_physics.models
   zfit_physics.unstable

Submodules
----------

.. toctree::
   :maxdepth: 4

   zfit_physics.pdf
